/*
    Open Altimeter -- an open-source altimeter for RC aircraft
    Copyright (C) 2010  Jony Hudson
    http://j-star.org/openaltimeter/

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "config.h"
#include "Battery.h"
#include "WProgram.h"

#include "Messages.h"
#include <math.h>

#define DIVIDER_RATIO 5.7 // the divider is a 1k resistor and a 4.7k resistor
#define MCU_SUPPLY_VOLTAGE 3.3

#define CONVERSION_FACTOR (DIVIDER_RATIO * MCU_SUPPLY_VOLTAGE) / 1024.0

Battery::Battery(int analogInputPin)
{
  _analogInputPin = analogInputPin;
}

void Battery::setup()
{
#ifdef LIPO
  // measure the LIPO voltage and work out the number of cells
  float v = readVoltage();
  _numberOfCells = floor(v / LIPO_CELL_DETECT_DIVISOR);
#endif
}

float Battery::readVoltage()
{
  return CONVERSION_FACTOR * analogRead(_analogInputPin);
}

boolean Battery::isLow()
{
#ifdef LIPO
  return (readVoltage() / _numberOfCells) < LIPO_LOW_VOLTAGE_PER_CELL_THRESHOLD;
#endif
#ifdef NIMH
  return readVoltage() < NIHM_LOW_VOLTAGE_THRESHOLD;
#endif
}

int Battery::numberOfCells()
{
  return _numberOfCells;
}

void Battery::test()
{
  printMessage(BATTERY_TEST_MESSAGE);
  printMessage(BATTERY_MESSAGE);
  Serial.println(readVoltage());
  printMessage(TEST_DONE_MESSAGE);
}
