/*
    Open Altimeter -- an open-source altimeter for RC aircraft
    Copyright (C) 2010  Jony Hudson
    http://j-star.org/openaltimeter/

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "notes.h"

// ** Hardware definitions **
#define BMP085_XCLR_PIN 17
#define BMP085_EOC_PIN 16
#define BEEPER_PIN 3
#define BATTERY_ANALOG_PIN 6
#define AT25DF_SS_PIN 10
#define RADIO_INPUT_PIN 8

// ** Configuration **
// -- pressure logging
#define ALTIMETER_SOFT_OVERSAMPLE 20
#define ALTIMETER_BASE_PRESSURE_SAMPLES 200
#define LOG_INTERVAL_MS 500
// height units: 3.281 for feet, 1.0 for metres.
#define HEIGHT_UNITS 3.281

// -- launch detector
// these parameters tune the launch detector - note that if you change HEIGHT UNITS or LOG_INTERVAL_MS you'll
// need to change these.
// this is the rate of climb that is considered a launch. It's measured in (height units)/(logging interval)
#define LAUNCH_CLIMB_THRESHOLD 10
// this is how many successive intervals have to exceed the launch climb rate to
// trigger the launch detector
#define LAUNCH_CLIMB_TIME 3
// this is how many samples to seek back after the launch was detected to find the
// minimum height
#define LAUNCH_SEEKBACK_SAMPLES 20

// -- low voltage alarm
// set the kind of battery - acceptable options are NONE, LIPO, NIMH
#define NIMH
// --- lipo options
// this is the voltage per cell that will trigger the low voltage alarm
#define LIPO_LOW_VOLTAGE_PER_CELL_THRESHOLD 3.5
#define LIPO_CELL_DETECT_DIVISOR 3.1
// --- NiMH options
#define NIHM_LOW_VOLTAGE_THRESHOLD 5.5

// -- radio control
// these define the servo pulse lengths that define the switch position. They are in us.
#define RADIO_MID_THRESHOLD_LOW 1400
#define RADIO_MID_THRESHOLD_HIGH 1600

// -- tunes and alarms
// startup tune
#define STARTUP_TUNE { NOTE_C7, 2, NOTE_D7, 2, NOTE_E7, 2, NOTE_F7, 2, NOTE_G7, 2, TUNE_END }
// alarms
#define LOW_VOLTAGE_TUNE { BEEPER_BEEP_FREQUENCY, 8, NOTE_REST, 8, TUNE_LOOP }
#define LOST_MODEL_TUNE { NOTE_C7, 2, NOTE_D7, 2, NOTE_E7, 2, NOTE_F7, 2, NOTE_G7, 2, NOTE_F7, 2, NOTE_E7, 2, NOTE_D7, 2, NOTE_C7, 2, NOTE_REST, 50, TUNE_LOOP }
#define BEEPER_BEEP_FREQUENCY 2000
#define BEEPER_INTEGER_TONE_DURATION 5
#define BEEPER_INTEGER_REST_DURATION 5
#define BEEPER_INTEGER_PAUSE_DURATION 15


